"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.AnimateSlider = void 0;

var _react = _interopRequireDefault(require("react"));

var _animateSliderModule = _interopRequireDefault(require("./animateSlider.module.scss"));

var _utils = require("../../utils");

var _jsxRuntime = require("react/jsx-runtime");

/**
 * This Component can be used to render Sliding Divs
 * in any direction one of which is Slider (SliderWrapper uses AnimateSlider)
 *
 * @author [Shubham Vishwakarma](http://192.168.23.38/shubhamvishwakarma)
 *
 * @maintainers [Shubham Vishwakarma](http://192.168.23.38/shubhamvishwakarma)
 */
class AnimateSlider extends _react.default.Component {
  constructor(...args) {
    super(...args);
    this.state = {
      style: {},
      sliderOpen: false
    };
    this.sliderContentRef = /*#__PURE__*/_react.default.createRef();
    this.stylesObj = {
      width: this.props.width || '100%',
      height: this.props.height || '100%'
    };

    this.toggle = (show, options = {}) => {
      if (show) {
        const newStyle = { ...this.stylesObj
        };
        newStyle.transform = 'translate3d(0px, 0px, 0px)';
        newStyle.WebkitTransform = 'translate3d(0px, 0px, 0px)';
        setTimeout(() => {
          this.setState({
            style: newStyle,
            sliderOpen: true
          }, () => {
            options.onToggleCB && options.onToggleCB();
          });
        }, this.props.duration || 1);
        (0, _utils.disableBodyScroll)(this.sliderContentRef.current, {
          allowTouchMove: el => {
            while (el && el !== document.body) {
              if (el.getAttribute('body-scroll-lock-ignore') !== null) {
                return true;
              }

              el = el.parentNode;
            }
          },
          hideBodyOverflow: true
        });
      } else {
        (0, _utils.enableBodyScroll)(this.sliderContentRef.current);
        this.closeSliderOnBack(options.onToggleCB);
      }
    };

    this.closeSliderOnBack = onToggle => {
      this.setState({
        style: this.stylesObj
      }, () => {
        setTimeout(() => {
          this.setState({
            sliderOpen: false
          });
          onToggle && onToggle();
        }, 200);
      });
    };

    this.componentWillUnmount = () => {
      (0, _utils.enableBodyScroll)(this.sliderContentRef.current);

      if (this.props.clearAllScrollLocks) {
        (0, _utils.clearAllBodyScrollLocks)();
      }
    };
  }

  render() {
    const {
      slideDirection,
      showOverlay,
      className,
      disableAnimation,
      onOverlayClick
    } = this.props;
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
        ref: this.sliderContentRef,
        className: `${(0, _utils.toModuleClass)(`animate-slider ${slideDirection} ${disableAnimation ? 'disable-animation' : ''}`, _animateSliderModule.default)}  ${className}`,
        style: this.state.style,
        children: this.state.sliderOpen && this.props.children
      }, `slider-${className}`), showOverlay && this.state.sliderOpen && /*#__PURE__*/(0, _jsxRuntime.jsx)("div", {
        className: `${(0, _utils.toModuleClass)(`animate-slider-overlay`, _animateSliderModule.default)} overlay-${className}`,
        onClick: onOverlayClick
      }, `slider-overlay-${className}`)]
    });
  }

}

exports.AnimateSlider = AnimateSlider;