"use strict";

exports.__esModule = true;
exports.getCurrentState = exports.getOpenSliders = exports.closeCurrent = exports.closeMultiSlider = exports.closeAll = exports.pushState = exports.removeBackHandler = exports.addBackHandler = exports.init = void 0;

var _bodyScrollLock = require("../body-scroll-lock");

/**
 * @author [Shubham Vishwakarma](http://192.168.23.38/shubhamvishwakarma)
 *
 * @maintainers [Shubham Vishwakarma](http://192.168.23.38/shubhamvishwakarma)
 */
const functionList = {};
const sliderList = [];
let prevState = null;
let reactBasePath = '';
let historyHandlerInitialized = false;
let historyRef = null;

class HistoryRef {
  constructor(value) {
    this._history = null;
    this._history = value;
  }

  get history() {
    return this._history;
  }

}

const addBackHandler = (key, func) => {
  if (typeof func === 'function') {
    functionList[key] = func;
  }
};

exports.addBackHandler = addBackHandler;

const removeBackHandler = (key, func) => {
  if (typeof func !== 'function') {
    return;
  }

  delete functionList[key];
};

exports.removeBackHandler = removeBackHandler;

const initializeHistoryHandler = (history, onPopState = () => {}, reInit) => {
  if (reInit) {
    sliderList.length = 0;
  }

  if (typeof window == 'undefined' || historyHandlerInitialized) {
    return;
  }

  historyHandlerInitialized = true;
  historyRef = new HistoryRef(history);
  historyRef.history.listen((location, action) => {
    if (action === 'PUSH') {
      return;
    }

    if (!prevState && (!location.state || !location.state.includes('-state'))) {
      onPopState();
      return;
    }

    if (action === 'POP') {
      if (prevState && functionList[prevState]) {
        functionList[prevState]();
      }

      const index = sliderList.findIndex(cur => cur === prevState);

      if (index != -1) {
        sliderList.splice(index, 1);
      }

      prevState = sliderList.length ? location.state : null;
    }
  });
  const temp = window.location.pathname;
  reactBasePath = temp.replace(new RegExp(historyRef.history.location.pathname + '$', 'i'), '');
};

exports.init = initializeHistoryHandler;

const pushState = state => {
  var _historyRef;

  if (!((_historyRef = historyRef) != null && _historyRef.history)) {
    return {
      err: 'History Handler not initialized'
    };
  }

  sliderList.push(state);
  prevState = state; // history.push(history.location.pathname + history.location.search, state);

  let uri = window.location.pathname + window.location.search + window.location.hash;
  uri = uri.replace(reactBasePath, '');
  historyRef.history.push(uri, state);
};

exports.pushState = pushState;

const closeAll = () => {
  closeMultiSlider(sliderList.length);
};

exports.closeAll = closeAll;

const closeMultiSlider = count => {
  if (!sliderList.length) {
    console.log('No Sliders are open');
    return;
  }

  if (count > sliderList.length) {
    count = sliderList.length;
  }

  console.log('Slider List : ', sliderList);
  let remaining = count;

  for (let i = sliderList.length - 1; i >= 0 && remaining > 0; i--) {
    const cur = sliderList[i];

    if (typeof functionList[cur] === 'function') {
      functionList[cur]();
      delete functionList[cur];
    }

    sliderList.splice(i, 1);
    remaining--;
  }

  if (!sliderList.length) {
    (0, _bodyScrollLock.clearAllBodyScrollLocks)();
  }

  window.history.go(-1 * count);
};

exports.closeMultiSlider = closeMultiSlider;

const closeCurrent = () => {
  window.history.back();
};

exports.closeCurrent = closeCurrent;

const getOpenSliders = (onlySliders = false) => {
  if (!onlySliders) {
    return sliderList;
  }

  return sliderList.filter(cur => cur.includes('-slider'));
};

exports.getOpenSliders = getOpenSliders;

const getCurrentState = () => {
  return window.history.state && window.history.state.state;
};

exports.getCurrentState = getCurrentState;