import React from 'react';
import styles from './animateSlider.module.scss';
import { toModuleClass } from '../../utils';
import { clearAllBodyScrollLocks, disableBodyScroll, enableBodyScroll } from '../../utils';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

/**
 * This Component can be used to render Sliding Divs
 * in any direction one of which is Slider (SliderWrapper uses AnimateSlider)
 *
 * @author [Shubham Vishwakarma](http://192.168.23.38/shubhamvishwakarma)
 *
 * @maintainers [Shubham Vishwakarma](http://192.168.23.38/shubhamvishwakarma)
 */
export class AnimateSlider extends React.Component {
  constructor(...args) {
    super(...args);
    this.state = {
      style: {},
      sliderOpen: false
    };
    this.sliderContentRef = /*#__PURE__*/React.createRef();
    this.stylesObj = {
      width: this.props.width || '100%',
      height: this.props.height || '100%'
    };

    this.toggle = (show, options = {}) => {
      if (show) {
        const newStyle = { ...this.stylesObj
        };
        newStyle.transform = 'translate3d(0px, 0px, 0px)';
        newStyle.WebkitTransform = 'translate3d(0px, 0px, 0px)';
        setTimeout(() => {
          this.setState({
            style: newStyle,
            sliderOpen: true
          }, () => {
            options.onToggleCB && options.onToggleCB();
          });
        }, this.props.duration || 1);
        disableBodyScroll(this.sliderContentRef.current, {
          allowTouchMove: el => {
            while (el && el !== document.body) {
              if (el.getAttribute('body-scroll-lock-ignore') !== null) {
                return true;
              }

              el = el.parentNode;
            }
          },
          hideBodyOverflow: true
        });
      } else {
        enableBodyScroll(this.sliderContentRef.current);
        this.closeSliderOnBack(options.onToggleCB);
      }
    };

    this.closeSliderOnBack = onToggle => {
      this.setState({
        style: this.stylesObj
      }, () => {
        setTimeout(() => {
          this.setState({
            sliderOpen: false
          });
          onToggle && onToggle();
        }, 200);
      });
    };

    this.componentWillUnmount = () => {
      enableBodyScroll(this.sliderContentRef.current);

      if (this.props.clearAllScrollLocks) {
        clearAllBodyScrollLocks();
      }
    };
  }

  render() {
    const {
      slideDirection,
      showOverlay,
      className,
      disableAnimation,
      onOverlayClick
    } = this.props;
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx("div", {
        ref: this.sliderContentRef,
        className: `${toModuleClass(`animate-slider ${slideDirection} ${disableAnimation ? 'disable-animation' : ''}`, styles)}  ${className}`,
        style: this.state.style,
        children: this.state.sliderOpen && this.props.children
      }, `slider-${className}`), showOverlay && this.state.sliderOpen && /*#__PURE__*/_jsx("div", {
        className: `${toModuleClass(`animate-slider-overlay`, styles)} overlay-${className}`,
        onClick: onOverlayClick
      }, `slider-overlay-${className}`)]
    });
  }

}